function [Input, Target] = InputTarget(hssp_profile, resStatus, neighbor, descriptor, encoding)
%
% Obtain information of inputs and targets for one protein. Standard
% deviation of each profile of residue is calculated and represented as the
% residue. For a window centred at the residue, members in the window
% accords with the normal distribution and the peak is at the central
% residue.
% 
% Input:
%       hssp_profile - sequence profile extracted from HSSP or other ways
%       resStatus    - residue status: interface or non-interface
%       neighbor     - the number of residues on both sides of the central
%                      residue
%       descriptor   - factor used to multiple with initial sequence
%                      profile, a l*D vector
%       descriptor   - encoding number
%
% Output:
%       Input  - an encoding matrixes for a protein or chain (with L
%                residues), with 20*(neighbor*2+1) * L dimensions
%       Target - a vector with L * 1 dimensions.
%
% Copyright Chen Peng NTU
% $Revision: 1.0 $   $Date: 2009/09/02 11:10:00 $

if isstruct(hssp_profile)
    Input = [];
    Target = [];
    names = fieldnames(hssp_profile);
    for j = 1 : size(names,1)
        P = [];
        T = [];
        if size(resStatus.(genvarname(names{j,1})),1) == ...
                size(hssp_profile.(genvarname(names{j,1})),1) && ...
                size(hssp_profile.(genvarname(names{j,1})),1) >= 30
            %% Encoding schema
            switch encoding 
                case {1} % encoding 1
                    for k = 1 : size(resStatus.(genvarname(names{j,1})),1) % for encoding 1 and 2
                        for l = 1 : 20 % multiple SP with a descriptor vector
                            P(k,l) = str2num(hssp_profile.(genvarname(names{j,1})){k,l+2})/100*descriptor(l,1); % descriptor(l,m);
                        end
                        P_std(k,1) = std(P(k,:),1);
                        T(k,1) = str2num(resStatus.(genvarname(names{j,1})){k,3});
                    end
                    lenSeq = size(P,1);
                    P1 = [];
                    for l = 1 : lenSeq
                        if l <= neighbor
                            for m = 1 : neighbor*2+1
                                P1(l,m) = P_std(m,1)*exp(-0.5*(l-m)^2/25);
                            end
                        elseif (lenSeq - l) <= neighbor
                            for m = lenSeq-neighbor*2 : lenSeq
                                P1(l,m-(lenSeq-neighbor*2)+1) = P_std(m,1)*exp(-0.5*(l-m)^2/25);
                            end
                        else
                            for m = l-neighbor : l+neighbor
                                P1(l,m-(l-neighbor)+1) = P_std(m,1)*exp(-0.5*(l-m)^2/25);
                            end
                        end
                    end
            end
            Input = [Input; single(P1)];
            Target = [Target; T];
        end
    end
else
    Input = [];
    Target = [];
    P = [];
    T = [];
    if size(resStatus,1) == ...
            size(hssp_profile,1) && ...
            size(hssp_profile,1) >= 30
            switch encoding 
                case {1} % encoding 1
                    for k = 1 : size(resStatus,1)
                        for l = 1 : 20 % multiple SP with a descriptor vector
                            P(k,l) = str2num(hssp_profile{k,l+2})/100*descriptor(l,1); 
                        end
                        P_std(k,1) = std(P(k,:),1); % P_std = P;
                        T(k,1) = str2num(resStatus{k,3});
                    end
                    lenSeq = size(P,1);
                    P1 = [];
                    for l = 1 : lenSeq
                        if l <= neighbor
                            for m = 1 : neighbor*2+1
                                P1(l,m) = P_std(m,1)*exp(-0.5*(l-m)^2/25);
                            end
                        elseif (lenSeq - l) <= neighbor
                            for m = lenSeq-neighbor*2 : lenSeq
                                P1(l,m-(lenSeq-neighbor*2)+1) = P_std(m,1)*exp(-0.5*(l-m)^2/25);
                            end
                        else
                            for m = l-neighbor : l+neighbor
                                P1(l,m-(l-neighbor)+1) = P_std(m,1)*exp(-0.5*(l-m)^2/25);
                            end
                        end
                    end
            end
        Input = P1;
        Target = T;
    end
end